::cisco::eem::event_register_syslog pattern "LINEPROTO-5-UPDOWN: Line protocol on Interface $check_intf, changed state to down" maxrun 3600
#-
# Copyright (c) 2010 Joe Marcus Clarke <jclarke@cisco.com>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
#
# This policy waits for an interface down syslog message for a given
# interface.  When the interface goes down, it collects the output from a
# number of cli commands, and stores them in a file.  It also collects cli
# output from a specified module.
#
# This policy takes the following environment variable(s):
#
# check_intf      : Name of the interface to watch.
#
# check_intf_file : Full patch to the file into which the command output
#                   will be saved.
#
# check_intf_mod  : Module from which additional CLI output will be collected.
#
#

if { ! [info exists check_intf_file] } {
    set result "ERROR: Policy cannot be run: variable check_intf_file has not been set"
    error $result $errorInfo
}

if { ! [info exists check_intf_mod] } {
    set result "ERROR: Policy cannot be run: variable check_intf_mod has not been set"
    error $result $errorInfo
}

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*

if { [catch {cli_open} result] } {
    error "Failed to open CLI session: '$result'" $errorInfo
}

array set cliarr $result

if { [catch {cli_exec $cliarr(fd) "enable"} result] } {
    error "Failed to enter enable mode: '$result'" $errorInfo
}

if { [catch {cli_exec $cliarr(fd) "show clock | append $check_intf_file"} result] } {
    error "Failed to execute 'show clock': '$result'" $errorInfo
}

if { [catch {cli_exec $cliarr(fd) "show log | append $check_intf_file"} result] } {
    error "Failed to execute 'show log': '$result'" $errorInfo
}

foreach cmd [list "show controllers serial 4/0/0/3:0" "show interface serial 4/0/0/3:0" "show hqf interface" "show policy-map interface serial 4/0/0/3:0"] {
    for { set i 0 } { $i < 5 } { incr i } {
	if { [catch {cli_exec $cliarr(fd) "$cmd | append $check_intf_file"} result] } {
	    error "Failed to execute command '$cmd': '$result'" $errorInfo
	}
	after 15000
    }
}

if { [catch {cli_exec $cliarr(fd) "show tech | append $check_intf_file"} result] } {
    error "Failed to execute 'show tech': '$result'" $errorInfo
}

foreach cmd [list "show platform software camp" "show proc cpu" "show platform software ibc" "show platform hard egos counters" "show platform hardware spi4 spa0" "show interfaces" "show controllers" "show platform hardware hyperion all" "show platform hyperion counters" "show platform hardware hyperion errors" "show platform hardware hyperion packet" "show platform hardware sonet" "show platform hardware iofpga" "show platform hardware ssa brief" "show platform hardware ssa counters" "show platform hardware ssa status" "show platform eos brief" "show platform eos counters" "show platform eos status"] {
    for { set i 0 } { $i < 5 } { incr i } {
	if { [catch {cli_exec $cliarr(fd) "remote command module $check_intf_mod $cmd | append $check_intf_file"} result] } {
	    error "Failed to execute command '$cmd': '$result'" $errorInfo
	}
	after 15000
    }
}

action_syslog msg "Commands have been written out to $check_intf_file"

if { [catch {cli_exec $cliarr(fd) "config t"} result] } {
    error "Failed to enter config mode: '$result'" $errorInfo
}

if { [catch {cli_exec $cliarr(fd) "interface Serial4/0/0/3:0"} result] } {
    error "Failed to enter interface sub-mode: '$result'" $errorInfo
}

if { [catch {cli_exec $cliarr(fd) "no service-policy output Parent"} result] } {
    error "Failed to disable service-policy: '$result'" $errorInfo
}

catch {cli_exec $cliarr(fd) "end"} ignore

action_syslog msg "Service-policy 'Parent' has been disabled on Serial4/0/0/3:0"

catch {cli_close $cliarr(fd) $cliarr(tty_id)} ignore
